@@ -9,18 +9,19 @@
 
 package org.gnu.gdk;
 import org.gnu.glib.GObject;
+import org.gnu.glib.Handle;
 /**
  *
  */
 public class PangoAttrEmbossed extends GObject 
 {
     /****************************************
-     * BEGINNING OF GENERATED CODE
+     * BEGINNING OF JNI CODE
      ****************************************/
-    native static final protected boolean getEmbossed (int obj);
-    native static final protected int gdk_pango_attr_embossed_new (boolean embossed);
+    native static final protected boolean getEmbossed (Handle obj);
+    native static final protected Handle gdk_pango_attr_embossed_new (boolean embossed);
     /****************************************
-     * END OF GENERATED CODE
+     * END OF JNI CODE
      ****************************************/
 }
 
