@@ -8,19 +8,22 @@
  */
 
 package org.gnu.gdk;
+
 import org.gnu.glib.Boxed;
+import org.gnu.glib.Handle;
+
 public class PixbufAnimationIter extends Boxed 
 {
+    
     /****************************************
-     * BEGINNING OF GENERATED CODE
+     * BEGINNING OF JNI CODE
      ****************************************/
     native static final protected int gdk_pixbuf_animation_iter_get_type ();
-    native static final protected int gdk_pixbuf_animation_iter_get_delay_time (int iter);
-    native static final protected int gdk_pixbuf_animation_iter_get_pixbuf (int iter);
-    native static final protected boolean gdk_pixbuf_animation_iter_on_currently_loading_frame (int 
-        iter);
+    native static final protected int gdk_pixbuf_animation_iter_get_delay_time (Handle iter);
+    native static final protected Handle gdk_pixbuf_animation_iter_get_pixbuf (Handle iter);
+    native static final protected boolean gdk_pixbuf_animation_iter_on_currently_loading_frame (Handle iter);
     /****************************************
-     * END OF GENERATED CODE
+     * END OF JNI CODE
      ****************************************/
 }
 
