@@ -9,15 +9,16 @@
 
 package org.gnu.gtk;
 
+import java.util.Vector;
+
 import org.gnu.glib.EventMap;
 import org.gnu.glib.EventType;
 import org.gnu.glib.GObject;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.gtk.event.ContainerEvent;
 import org.gnu.gtk.event.ContainerListener;
 
-import java.util.Vector;
-
 /**
  * The Container widget is a base class for container widgets.
  * Widgets that inherit from Container have the ability to contain,
@@ -25,7 +26,7 @@ import java.util.Vector;
  */
 public class Container extends Widget {
 
-	protected Container(int handle) {
+	protected Container(Handle handle) {
 		super(handle);
 	}
 
@@ -98,7 +99,7 @@ public class Container extends Widget {
 	 * @return An array contain all children of this container or null.
 	 */
 	public Widget[] getChildren() {
-		int[] hndls = gtk_container_get_children(getHandle());
+	    Handle[] hndls = gtk_container_get_children(getHandle());
 		if (null == hndls)
 			return null;
 		Widget[] widgets = new Widget[hndls.length];
@@ -221,31 +222,27 @@ public class Container extends Widget {
 		anEvtMap.addEvent("set_focus_child", "handleSetFocusChild", ContainerEvent.Type.SET_FOCUS_CHILD, ContainerListener.class);
 	}
 
-	/****************************************
-	 * BEGINNING OF GENERATED CODE
-	 ****************************************/
+
 	native static final protected int gtk_container_get_type();
-	native static final protected void gtk_container_set_border_width(int container, int borderWidth);
-	native static final protected int gtk_container_get_border_width(int container);
-	native static final protected void gtk_container_add(int container, int widget);
-	native static final protected void gtk_container_remove(int container, int widget);
-	native static final protected void gtk_container_set_resize_mode(int container, int mode);
-	native static final protected int gtk_container_get_resize_mode(int container);
-	native static final protected void gtk_container_check_resize(int container);
-	native static final protected int[] gtk_container_get_children(int container);
-	native static final protected void gtk_container_propagate_expose(int container, int child, int event);
-	native static final protected void gtk_container_set_focus_chain(int container, int focusableWidgets);
-	native static final protected boolean gtk_container_get_focus_chain(int container, int[] focusableWidgets);
-	native static final protected void gtk_container_unset_focus_chain(int container);
-	native static final protected void gtk_container_set_reallocate_redraws(int container, boolean needsRedraws);
-	native static final protected void gtk_container_set_focus_child(int container, int child);
-	native static final protected void gtk_container_set_focus_vadjustment(int container, int adjustment);
-	native static final protected int gtk_container_get_focus_vadjustment(int container);
-	native static final protected void gtk_container_set_focus_hadjustment(int container, int adjustment);
-	native static final protected int gtk_container_get_focus_hadjustment(int container);
-	native static final protected void gtk_container_resize_children(int container);
-	native static final protected int gtk_container_child_type(int container);
-	/****************************************
-	 * END OF GENERATED CODE
-	 ****************************************/
+	native static final protected void gtk_container_set_border_width(Handle container, int borderWidth);
+	native static final protected int gtk_container_get_border_width(Handle container);
+	native static final protected void gtk_container_add(Handle container, Handle widget);
+	native static final protected void gtk_container_remove(Handle container, Handle widget);
+	native static final protected void gtk_container_set_resize_mode(Handle container, int mode);
+	native static final protected int gtk_container_get_resize_mode(Handle container);
+	native static final protected void gtk_container_check_resize(Handle container);
+	native static final protected Handle[] gtk_container_get_children(Handle container);
+	native static final protected void gtk_container_propagate_expose(Handle container, Handle child, Handle event);
+	native static final protected void gtk_container_set_focus_chain(Handle container, Handle focusableWidgets);
+	native static final protected boolean gtk_container_get_focus_chain(Handle container, Handle focusableWidgets);
+	native static final protected void gtk_container_unset_focus_chain(Handle container);
+	native static final protected void gtk_container_set_reallocate_redraws(Handle container, boolean needsRedraws);
+	native static final protected void gtk_container_set_focus_child(Handle container, Handle child);
+	native static final protected void gtk_container_set_focus_vadjustment(Handle container, Handle adjustment);
+	native static final protected Handle gtk_container_get_focus_vadjustment(Handle container);
+	native static final protected void gtk_container_set_focus_hadjustment(Handle container, Handle adjustment);
+	native static final protected Handle gtk_container_get_focus_hadjustment(Handle container);
+	native static final protected void gtk_container_resize_children(Handle container);
+	native static final protected int gtk_container_child_type(Handle container);
+
 }
