@@ -242,7 +242,7 @@ public class Label extends Misc {
 	 */
 	public Widget getMnemonicWidget() {
 	    Handle hndl = gtk_label_get_mnemonic_widget(getHandle());
-		GObject obj = getGObjectFromHandle(hndl);
+		GObject obj = retrieveGObject(hndl);
 		if (null != obj)
 			return (Widget)obj;
 		return new Widget(hndl);
@@ -362,6 +362,92 @@ public class Label extends Misc {
 		}
 	}
 
+	/**
+	 * Sets the desired width in characters of label to chars.
+	 *
+	 * @param chars the new desired width, in characters.
+	 * @since 2.6 
+	 */
+	public void setWidthChars(int chars){
+		gtk_label_set_width_chars(getHandle(), chars);
+	}
+
+	/**
+	 * Retrieves the desired width of label, in characters. 
+	 *
+	 * @see #SetWidthChars(int)
+	 * @return the width of the label in characters.
+	 * @since 2.6 
+	 */
+	public int getWidthChars(){
+		return gtk_label_get_width_chars(getHandle());
+	}
+
+	/**
+	 * Sets the desired maximum width in characters to chars.
+	 *
+	 * @param chars the new desired maximum width, in characters.
+	 * @since 2.6 
+	 */
+	public void setMaxWidthChars(int chars){
+		 gtk_label_set_max_width_chars(getHandle(), chars);
+	}
+
+	/** 
+	 * Retrieves the desired maximum width of label, in characters. 
+	 *
+	 * @see #SetMaxWidthChars(int)
+	 * @return the maximum width of the label in characters.
+	 * @since 2.6
+	 */
+	public int getMaxWidthChars(){
+		return gtk_label_get_max_width_chars(getHandle());
+	}
+
+	/**
+	 * Sets the angle of rotation for the label. An angle of 90 reads from from
+	 * bottom to top, an angle of 270, from top to bottom. The angle setting for
+	 * the label is ignored if the label is selectable, wrapped, or ellipsized.
+	 *
+	 * @param angle	the angle that the baseline of the label makes with the
+	 * horizontal, in degrees, measured counterclockwise
+	 *
+	 * @since 2.6 
+	 */
+	public void setAngle(double angle){
+		gtk_label_set_angle(getHandle(), angle);
+	}
+
+	/** 
+	 * Gets the angle of rotation for the label. 
+	 *
+	 * @see #SetAngle(double)
+	 * @return	the angle of rotation for the label
+	 * @since 2.6 
+	 */
+	public double getAngle(){
+		return gtk_label_get_angle(getHandle());
+	}
+	
+	/**
+	 * Sets whether the label is in single line mode.
+	 * @param singleLineMode true if the label should be in single line mode
+	 * @since 2.6 
+	 */
+	public void setSingleLineMode(boolean singleLineMode){
+		gtk_label_set_single_line_mode(getHandle(), singleLineMode);
+	}
+
+	/**
+	 * Returns whether the label is in single line mode.
+	 * @return true when the label is in single line mode.
+	 * @since 2.6 
+	 */
+	public boolean getSingleLineMode(){
+		return gtk_label_get_single_line_mode(getHandle());
+	}
+
+
 	/**
 	 * Retrieve the runtime type used by the GLib library.
 	 */
@@ -408,11 +494,6 @@ public class Label extends Misc {
     native static final private double gtk_label_get_angle(Handle label);
     native static final private void gtk_label_set_single_line_mode(Handle label, boolean single_line_mode);
     native static final private boolean gtk_label_get_single_line_mode(Handle label);
-    native static final private void gtk_label_set_ellipsize(Handle label, int mode);
-    native static final private int gtk_label_get_ellipsize(Handle label);
 
-    /* Deprecated functions.
-    native static final private void gtk_label_get(Handle label, char** str);
-    native static final private int gtk_label_parse_uline(Handle label, String string);
-    */
+
 }
