@@ -61,14 +61,10 @@ public class TextBuffer extends GObject {
 	}
 
 	/**
- Gets the number of characters in the buffer. Note that
-	 * characters and
- bytes are not the same. You can't expect
-	 * the contents of the buffer
- in string form to be this many
-	 * bytes long. The character count is cached,
- so this
-	 * function is very fast.
+	 * Gets the number of characters in the buffer; note that characters and
+	 * bytes are not the same, you can't e.g. expect the contents of the buffer
+	 * in string form to be this many bytes long. The character count is cached,
+	 * so this function is very fast.
 	 * @return Number of characters in the buffer.
 	 */
 	public int getCharCount() {
@@ -81,7 +77,7 @@ public class TextBuffer extends GObject {
 	 */
 	public TextTagTable getTextTagTable() {
 	    Handle hndl = gtk_text_buffer_get_tag_table(getHandle());
-		GObject obj = getGObjectFromHandle(hndl);
+		GObject obj = retrieveGObject(hndl);
 		if (null != obj)
 			return (TextTagTable)obj;
 		return new TextTagTable(hndl);
@@ -395,7 +391,7 @@ public class TextBuffer extends GObject {
 	    Handle markHandle = gtk_text_buffer_get_mark(getHandle(), name);
 		if (null == markHandle)
 			return null;
-		GObject obj = getGObjectFromHandle(markHandle);
+		GObject obj = retrieveGObject(markHandle);
 		if (null != obj)
 			return (TextMark)obj;
 		return new TextMark(markHandle);
@@ -409,7 +405,7 @@ public class TextBuffer extends GObject {
 	 */
 	public TextMark getInsert() {
 	    Handle hndl = gtk_text_buffer_get_insert(getHandle());
-		GObject obj = getGObjectFromHandle(hndl);
+		GObject obj = retrieveGObject(hndl);
 		if (null != obj)
 			return (TextMark)obj;
 		return new TextMark(hndl);
@@ -427,7 +423,7 @@ public class TextBuffer extends GObject {
 	 */
 	public TextMark getSelectionBound() {
 	    Handle hndl = gtk_text_buffer_get_selection_bound(getHandle());
-		GObject obj = getGObjectFromHandle(hndl);
+		GObject obj = retrieveGObject(hndl);
 		if (null != obj)
 			return (TextMark)obj;
 		return new TextMark(hndl);
@@ -595,7 +591,7 @@ public class TextBuffer extends GObject {
 	 * of the selection will be considered (users can't delete uneditable text).
 	 * @param interactive Whether the deletion is caused by user interaction
 	 * @param defaultEditable Whether the buffer is editable by default
-	 * @return Whether there was a non-empty selection to delete
+	 * @returns Whether there was a non-empty selection to delete
 	 */
 	public boolean deleteSelection(boolean interactive, boolean defaultEditable) {
 		return gtk_text_buffer_delete_selection(getHandle(), interactive, defaultEditable);
@@ -851,7 +847,7 @@ public class TextBuffer extends GObject {
 		return list.indexOf(listener);
 	}
 
-	private void handleApplyTag(Handle tag, Handle startIter, Handle endIter) {
+	private void handleApplyTag(int tag, int startIter, int endIter) {
 		fireTextBufferEvent(new TextBufferEvent(this, TextBufferEvent.Type.APPLY_TAG));
 	}
 
@@ -859,27 +855,27 @@ public class TextBuffer extends GObject {
 		fireTextBufferEvent(new TextBufferEvent(this, TextBufferEvent.Type.CHANGED));
 	}
 
-	private void handleDeleteRange(Handle startIter, Handle endIter) {
+	private void handleDeleteRange(int startIter, int endIter) {
 		fireTextBufferEvent(new TextBufferEvent(this, TextBufferEvent.Type.DELETE_RANGE));
 	}
 
-	private void handleInsertChildAnchor(Handle position, Handle childAnchor) {
+	private void handleInsertChildAnchor(int position, int childAnchor) {
 		fireTextBufferEvent(new TextBufferEvent(this, TextBufferEvent.Type.INSERT_CHILD_ANCHOR));
 	}
 
-	private void handleInsertPixbuf(Handle position, Handle pixbuf) {
+	private void handleInsertPixbuf(int position, int pixbuf) {
 		fireTextBufferEvent(new TextBufferEvent(this, TextBufferEvent.Type.INSERT_PIXBUF));
 	}
 
-	private void handleInsertText(Handle position, String text, int length) {
+	private void handleInsertText(int position, String text, int length) {
 		fireTextBufferEvent(new TextBufferEvent(this, TextBufferEvent.Type.INSERT_TEXT));
 	}
 
-	private void handleMarkDelete(Handle mark) {
+	private void handleMarkDelete(int mark) {
 		fireTextBufferEvent(new TextBufferEvent(this, TextBufferEvent.Type.MARK_DELETED));
 	}
 
-	private void handleMarkSet(Handle location, Handle mark) {
+	private void handleMarkSet(int location, int mark) {
 		fireTextBufferEvent(new TextBufferEvent(this, TextBufferEvent.Type.MARK_SET));
 	}
 
@@ -887,7 +883,7 @@ public class TextBuffer extends GObject {
 		fireTextBufferEvent(new TextBufferEvent(this, TextBufferEvent.Type.MODIFIED_CHANGED));
 	}
 
-	private void handleRemoveTag(Handle tag, Handle startChar, Handle endChar) {
+	private void handleRemoveTag(int tag, int startChar, int endChar) {
 		fireTextBufferEvent(new TextBufferEvent(this, TextBufferEvent.Type.REMOVE_TAG));
 	}
 
@@ -973,5 +969,4 @@ public class TextBuffer extends GObject {
 	native static final protected Handle gtk_text_buffer_get_start_iterMOD(Handle buffer);
 	native static final protected Handle gtk_text_buffer_get_end_iterMOD(Handle buffer);
 	native protected static final void gtk_text_buffer_paste_clipboardInsertPosition(Handle handle, Handle clip, boolean editable);
-
 }
