@@ -12,12 +12,12 @@ package org.gnu.gtk;
 import java.util.Vector;
 
 import org.gnu.glib.EventMap;
+import org.gnu.glib.EventType;
 import org.gnu.glib.GObject;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.gtk.event.TextViewEvent;
 import org.gnu.gtk.event.TextViewListener;
-import org.gnu.gtk.event.GtkEventType;
-import org.gnu.gtk.event.TreeViewEvent;
 
 /**
  * <h2>Conceptual Overview</h2>
@@ -112,7 +112,7 @@ public class TextView extends Container {
 	/**
 	 * Construct a TextView from a handle to a native resource.
 	 */
-	public TextView(int handle) {
+	public TextView(Handle handle) {
 		super(handle);
 	}
 
@@ -129,7 +129,7 @@ public class TextView extends Container {
 	 * @return The buffer used in the widget.
 	 */
 	public TextBuffer getBuffer() {
-		int hndl = gtk_text_view_get_buffer(getHandle());
+	    Handle hndl = gtk_text_view_get_buffer(getHandle());
 		GObject obj = retrieveGObject(hndl);
 		if (null != obj)
 			return (TextBuffer)obj;
@@ -387,8 +387,8 @@ public class TextView extends Container {
 		return cls;
 	}
 
-	public GtkEventType getEventType(String signal) {
-		GtkEventType et = evtMap.getEventType(signal);
+	public EventType getEventType(String signal) {
+		EventType et = evtMap.getEventType(signal);
 		if (et == null) et = super.getEventType(signal);
 		return et;
 	}
@@ -525,7 +525,7 @@ public class TextView extends Container {
 		fireTextViewEvent(new TextViewEvent(this, TextViewEvent.Type.PAGE_HORIZONTALLY));
 	}
 
-	private void handlePopulatePopup(int menu) {
+	private void handlePopulatePopup(Handle menu) {
 		TextViewEvent tve = new TextViewEvent(this, TextViewEvent.Type.POPULATE_POPUP);
 		GObject obj = retrieveGObject(menu);
 		if (null != obj)
@@ -554,97 +554,61 @@ public class TextView extends Container {
 		return new Type(gtk_text_view_get_type());
 	}
 
-	protected native static final void gtk_text_view_set_accepts_tab   (int view, boolean setting);
-	protected native static final boolean gtk_text_view_get_accepts_tab (int textview);
-	protected native static final void gtk_text_view_set_overwrite (int view, boolean setting );
-	protected native static final boolean gtk_text_view_get_overwrite( int view );
-
-	/****************************************
-	 * BEGINNING OF GENERATED CODE
-	 ****************************************/
 	native static final protected int gtk_text_view_get_type();
-	native static final protected int gtk_text_view_new();
-	native static final protected int gtk_text_view_new_with_buffer(int buffer);
-	native static final protected void gtk_text_view_set_buffer(int textView, int buffer);
-	native static final protected int gtk_text_view_get_buffer(int textView);
-	native static final protected boolean gtk_text_view_scroll_to_iter(
-		int textView,
-		int iter,
-		double withinMargin,
-		boolean useAlign,
-		double xalign,
-		double yalign);
-	native static final protected void gtk_text_view_scroll_to_mark(
-		int textView,
-		int mark,
-		double withinMargin,
-		boolean useAlign,
-		double xalign,
-		double yalign);
-	native static final protected void gtk_text_view_scroll_mark_onscreen(int textView, int mark);
-	native static final protected boolean gtk_text_view_move_mark_onscreen(int textView, int mark);
-	native static final protected boolean gtk_text_view_place_cursor_onscreen(int textView);
-	native static final protected void gtk_text_view_get_visible_rect(int textView, int visibleRect);
-	native static final protected void gtk_text_view_set_cursor_visible(int textView, boolean setting);
-	native static final protected boolean gtk_text_view_get_cursor_visible(int textView);
-	native static final protected void gtk_text_view_get_iter_location(int textView, int iter, int location);
-	native static final protected void gtk_text_view_get_iter_at_location(int textView, int iter, int x, int y);
-	native static final protected void gtk_text_view_get_line_yrange(int textView, int iter, int[] y, int[] height);
-	native static final protected void gtk_text_view_get_line_at_y(int textView, int targetIter, int y, int[] lneTop);
-	native static final protected void gtk_text_view_buffer_to_window_coords(
-		int textView,
-		int win,
-		int bufferX,
-		int bufferY,
-		int[] windowX,
-		int[] windowY);
-	native static final protected void gtk_text_view_window_to_buffer_coords(
-		int textView,
-		int win,
-		int windowX,
-		int windowY,
-		int[] bufferX,
-		int[] bufferY);
-	native static final protected int gtk_text_view_get_window(int textView, int win);
-	native static final protected int gtk_text_view_get_window_type(int textView, int window);
-	native static final protected void gtk_text_view_set_border_window_size(int textView, int type, int size);
-	native static final protected int gtk_text_view_get_border_window_size(int textView, int type);
-	native static final protected boolean gtk_text_view_forward_display_line(int textView, int iter);
-	native static final protected boolean gtk_text_view_backward_display_line(int textView, int iter);
-	native static final protected boolean gtk_text_view_forward_display_line_end(int textView, int iter);
-	native static final protected boolean gtk_text_view_backward_display_line_start(int textView, int iter);
-	native static final protected boolean gtk_text_view_starts_display_line(int textView, int iter);
-	native static final protected boolean gtk_text_view_move_visually(int textView, int iter, int count);
-	native static final protected void gtk_text_view_add_child_at_anchor(int textView, int child, int anchor);
-	native static final protected void gtk_text_view_add_child_in_window(
-		int textView,
-		int child,
-		int whichWindow,
-		int xpos,
-		int ypos);
-	native static final protected void gtk_text_view_move_child(int textView, int child, int xpos, int ypos);
-	native static final protected void gtk_text_view_set_wrap_mode(int textView, int wrapMode);
-	native static final protected int gtk_text_view_get_wrap_mode(int textView);
-	native static final protected void gtk_text_view_set_editable(int textView, boolean setting);
-	native static final protected boolean gtk_text_view_get_editable(int textView);
-	native static final protected void gtk_text_view_set_pixels_above_lines(int textView, int pixelsAboveLines);
-	native static final protected int gtk_text_view_get_pixels_above_lines(int textView);
-	native static final protected void gtk_text_view_set_pixels_below_lines(int textView, int pixelsBelowLines);
-	native static final protected int gtk_text_view_get_pixels_below_lines(int textView);
-	native static final protected void gtk_text_view_set_pixels_inside_wrap(int textView, int pixelsInsideWrap);
-	native static final protected int gtk_text_view_get_pixels_inside_wrap(int textView);
-	native static final protected void gtk_text_view_set_justification(int textview, int justification);
-	native static final protected int gtk_text_view_get_justification(int textView);
-	native static final protected void gtk_text_view_set_left_margin(int textView, int leftMargin);
-	native static final protected int gtk_text_view_get_left_margin(int textView);
-	native static final protected void gtk_text_view_set_right_margin(int textView, int rightMargin);
-	native static final protected int gtk_text_view_get_right_margin(int textView);
-	native static final protected void gtk_text_view_set_indent(int textView, int indent);
-	native static final protected int gtk_text_view_get_indent(int textView);
-	native static final protected void gtk_text_view_set_tabs(int textView, int tabs);
-	native static final protected int gtk_text_view_get_tabs(int textView);
-	native static final protected int gtk_text_view_get_default_attributes(int textView);
-	/****************************************
-	 * END OF GENERATED CODE
-	 ****************************************/
+	native static final protected Handle gtk_text_view_new();
+	native static final protected Handle gtk_text_view_new_with_buffer(Handle buffer);
+	native static final protected void gtk_text_view_set_buffer(Handle textView, Handle buffer);
+	native static final protected Handle gtk_text_view_get_buffer(Handle textView);
+	native static final protected boolean gtk_text_view_scroll_to_iter(Handle textView, Handle iter, double withinMargin, boolean useAlign, double xalign, double yalign);
+	native static final protected void gtk_text_view_scroll_to_mark(Handle textView,Handle mark,double withinMargin,boolean useAlign,double xalign,double yalign);
+	native static final protected void gtk_text_view_scroll_mark_onscreen(Handle textView, Handle mark);
+	native static final protected boolean gtk_text_view_move_mark_onscreen(Handle textView, Handle mark);
+	native static final protected boolean gtk_text_view_place_cursor_onscreen(Handle textView);
+	native static final protected void gtk_text_view_get_visible_rect(Handle textView, Handle visibleRect);
+	native static final protected void gtk_text_view_set_cursor_visible(Handle textView, boolean setting);
+	native static final protected boolean gtk_text_view_get_cursor_visible(Handle textView);
+	native static final protected void gtk_text_view_get_iter_location(Handle textView, Handle iter, int location);
+	native static final protected void gtk_text_view_get_iter_at_location(Handle textView, Handle iter, int x, int y);
+	native static final protected void gtk_text_view_get_line_yrange(Handle textView, Handle iter, int[] y, int[] height);
+	native static final protected void gtk_text_view_get_line_at_y(Handle textView, Handle targetIter, int y, int[] lneTop);
+	native static final protected void gtk_text_view_buffer_to_window_coords(Handle textView,int win,int bufferX,int bufferY,int[] windowX,int[] windowY);
+	native static final protected void gtk_text_view_window_to_buffer_coords(Handle textView,int win,int windowX,int windowY,int[] bufferX,int[] bufferY);
+	native static final protected Handle gtk_text_view_get_window(Handle textView, int win);
+	native static final protected int gtk_text_view_get_window_type(Handle textView, Handle window);
+	native static final protected void gtk_text_view_set_border_window_size(Handle textView, int type, int size);
+	native static final protected int gtk_text_view_get_border_window_size(Handle textView, int type);
+	native static final protected boolean gtk_text_view_forward_display_line(Handle textView, Handle iter);
+	native static final protected boolean gtk_text_view_backward_display_line(Handle textView, Handle iter);
+	native static final protected boolean gtk_text_view_forward_display_line_end(Handle textView, Handle iter);
+	native static final protected boolean gtk_text_view_backward_display_line_start(Handle textView, Handle iter);
+	native static final protected boolean gtk_text_view_starts_display_line(Handle textView, Handle iter);
+	native static final protected boolean gtk_text_view_move_visually(Handle textView, Handle iter, int count);
+	native static final protected void gtk_text_view_add_child_at_anchor(Handle textView, Handle child, Handle anchor);
+	native static final protected void gtk_text_view_add_child_in_window(Handle textView,Handle child,int whichWindow,int xpos,int ypos);
+	native static final protected void gtk_text_view_move_child(Handle textView, Handle child, int xpos, int ypos);
+	native static final protected void gtk_text_view_set_wrap_mode(Handle textView, int wrapMode);
+	native static final protected int gtk_text_view_get_wrap_mode(Handle textView);
+	native static final protected void gtk_text_view_set_editable(Handle textView, boolean setting);
+	native static final protected boolean gtk_text_view_get_editable(Handle textView);
+	native static final protected void gtk_text_view_set_pixels_above_lines(Handle textView, int pixelsAboveLines);
+	native static final protected int gtk_text_view_get_pixels_above_lines(Handle textView);
+	native static final protected void gtk_text_view_set_pixels_below_lines(Handle textView, int pixelsBelowLines);
+	native static final protected int gtk_text_view_get_pixels_below_lines(Handle textView);
+	native static final protected void gtk_text_view_set_pixels_inside_wrap(Handle textView, int pixelsInsideWrap);
+	native static final protected int gtk_text_view_get_pixels_inside_wrap(Handle textView);
+	native static final protected void gtk_text_view_set_justification(Handle textView, int justification);
+	native static final protected int gtk_text_view_get_justification(Handle textView);
+	native static final protected void gtk_text_view_set_left_margin(Handle textView, int leftMargin);
+	native static final protected int gtk_text_view_get_left_margin(Handle textView);
+	native static final protected void gtk_text_view_set_right_margin(Handle textView, int rightMargin);
+	native static final protected int gtk_text_view_get_right_margin(Handle textView);
+	native static final protected void gtk_text_view_set_indent(Handle textView, int indent);
+	native static final protected int gtk_text_view_get_indent(Handle textView);
+	native static final protected void gtk_text_view_set_tabs(Handle textView, Handle tabs);
+	native static final protected Handle gtk_text_view_get_tabs(Handle textView);
+	native static final protected Handle gtk_text_view_get_default_attributes(Handle textView);
+	protected native static final void gtk_text_view_set_accepts_tab   (Handle view, boolean setting);
+	protected native static final boolean gtk_text_view_get_accepts_tab (Handle textview);
+	protected native static final void gtk_text_view_set_overwrite (Handle view, boolean setting );
+	protected native static final boolean gtk_text_view_get_overwrite( Handle view );
 }
