@@ -14,6 +14,7 @@ import java.util.Vector;
 import org.gnu.glib.EventMap;
 import org.gnu.glib.EventType;
 import org.gnu.glib.GObject;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.gtk.event.TreeViewEvent;
 import org.gnu.gtk.event.TreeViewListener;
@@ -118,7 +119,7 @@ public class TreeView extends Container {
 	/**
 	 * Creates a new tree view from a native handle
 	 */
-	public TreeView(int handle) {
+	public TreeView(Handle handle) {
 		super(handle);
 	}
 
@@ -133,7 +134,7 @@ public class TreeView extends Container {
 	 * Returns the model associated with this tree.
 	 */
 	public TreeModel getModel() {
-		int hndl = gtk_tree_view_get_model(getHandle());
+	    Handle hndl = gtk_tree_view_get_model(getHandle());
 		GObject obj = retrieveGObject(hndl);
 		if (null != obj)
 			return (TreeModel)obj;
@@ -174,7 +175,7 @@ public class TreeView extends Container {
 	 * Gets the TreeSelection associated with this widget
 	 */
 	public TreeSelection getSelection() {
-		int hndl = gtk_tree_view_get_selection(getHandle());
+	    Handle hndl = gtk_tree_view_get_selection(getHandle());
 		GObject obj = retrieveGObject(hndl);
 		if (null != obj)
 			return (TreeSelection)obj;
@@ -186,7 +187,7 @@ public class TreeView extends Container {
 	 * @return A GtkAdjustment object, or NULL if none is currently being used.
 	 */
 	public Adjustment getHAdjustment() {
-		int hndl = gtk_tree_view_get_hadjustment(getHandle());
+	    Handle hndl = gtk_tree_view_get_hadjustment(getHandle());
 		GObject obj = retrieveGObject(hndl);
 		if (null != obj)
 			return (Adjustment)obj;
@@ -267,8 +268,8 @@ public class TreeView extends Container {
 	 * of columns.
 	 */
 	public TreeViewColumn getColumn(int position) {
-		int h = gtk_tree_view_get_column(getHandle(), position);
-		if (h < 0)
+	    Handle h = gtk_tree_view_get_column(getHandle(), position);
+		if (h == null)
 			return null;
 		GObject obj = retrieveGObject(h);
 		if (null != obj)
@@ -298,8 +299,8 @@ public class TreeView extends Container {
 	}
 	
 	public TreeViewColumn getExpanderColumn() {
-		int hndl = gtk_tree_view_get_expander_column(getHandle());
-		if (hndl < 0)
+	    Handle hndl = gtk_tree_view_get_expander_column(getHandle());
+		if (hndl == null)
 			return null;
 		GObject obj = retrieveGObject(hndl);
 		if (null != obj)
@@ -356,7 +357,7 @@ public class TreeView extends Container {
 	 * @param column The TreeViewColumn to move horizontally to
 	 */
 	public void scrollToCell(TreeViewColumn column) {
-		gtk_tree_view_scroll_to_cell(getHandle(), 0, column.getHandle(), false, 0, 0);
+		gtk_tree_view_scroll_to_cell(getHandle(), null, column.getHandle(), false, 0, 0);
 	}
 
 	/**
@@ -365,7 +366,7 @@ public class TreeView extends Container {
 	 * @param path The path of the row to move to, or NULL.
 	 */
 	public void scrollToCell(TreePath path) {
-		gtk_tree_view_scroll_to_cell(getHandle(), path.getHandle(), 0, false, 0, 0);
+		gtk_tree_view_scroll_to_cell(getHandle(), path.getHandle(), null, false, 0, 0);
 	}
 
 	/**
@@ -388,23 +389,21 @@ public class TreeView extends Container {
 	 * Returns the current path
 	 */
 	public TreePath getCursorPath() {
-		int[] path = new int[1];
-		int[] column = new int[1];
-		gtk_tree_view_get_cursor(getHandle(), path, column);
-		return new TreePath(path[0]);
+		Handle path = GObject.getNullHandle();
+		gtk_tree_view_get_cursor(getHandle(), path, null);
+		return new TreePath(path);
 	}
 
 	/** 
 	 * Returns the current column 
 	 */
 	public TreeViewColumn getCursorColumn() {
-		int[] path = new int[1];
-		int[] column = new int[1];
-		gtk_tree_view_get_cursor(getHandle(), path, column);
-		GObject obj = retrieveGObject(column[0]);
+		Handle column = GObject.getNullHandle();
+		gtk_tree_view_get_cursor(getHandle(), null, column);
+		GObject obj = retrieveGObject(column);
 		if (null != obj)
 			return (TreeViewColumn)obj;
-		return new TreeViewColumn(column[0]);
+		return new TreeViewColumn(column);
 	}
 
 	/**
@@ -508,7 +507,7 @@ public class TreeView extends Container {
 	 * Returns an array of all the columns currently in the view
 	 */
 	public TreeViewColumn[] getColumns(){
-		int[] hndls = gtk_tree_view_get_columns(getHandle());
+	    Handle[] hndls = gtk_tree_view_get_columns(getHandle());
 		if (null == hndls)
 			return null;
 		TreeViewColumn[] columns = new TreeViewColumn[hndls.length];
@@ -579,21 +578,43 @@ public class TreeView extends Container {
 		return gtk_tree_view_get_enable_search(getHandle());
 	}
 
+    /**
+     * @deprecated This method is broken and has been deprecated in favor of
+     * the {@link #setSearchDataColumn} method.
+     */
+    public void setSearchColumn(TreeViewColumn column) {
+        throw new RuntimeException( "This method is deprecated." +
+                                    "please use the method: "+
+                                    "TreeView#setSearchDataColumn(DataColumn)" );
+    }
+    /**
+     * @deprecated This method is broken and has been deprecated in favor of
+     * the {@link #getSearchDataColumn} method.
+     */
+    public TreeViewColumn getSearchColumn() {
+        throw new RuntimeException( "This method is deprecated." +
+                                    "please use the method: "+
+                                    "TreeView#getSearchDataColumn()" );
+    }
 	/**
 	 * Sets column as the column where the interactive search code should 
 	 * search in. Additionally, turns on interactive searching.
-	 * @param column The column to search in
+	 * @param column The column of the data model to search in.
 	 */
-	public void setSearchColumn(TreeViewColumn column) {
-		gtk_tree_view_set_search_column(getHandle(), column.getHandle());
+	public void setSearchDataColumn(DataColumn column) {
+		gtk_tree_view_set_search_column(getHandle(), column.getColumn());
 	}
 	
-	public TreeViewColumn getSearchColumn() {
-		int hndl = gtk_tree_view_get_search_column(getHandle());
-		GObject obj = retrieveGObject(hndl);
-		if (null != obj)
-			return (TreeViewColumn)obj;
-		return new TreeViewColumn(hndl);
+    /**
+     * Gets the column searched on by the interactive search code.
+     * @return A DataColumn object representing the column of the data model 
+     * in which the interactive search takes place.
+     */
+	public DataColumn getSearchDataColumn() {
+	    int datacol = gtk_tree_view_get_search_column(getHandle());
+            DataColumn dataColumn = new DataColumnInt();
+            dataColumn.setColumn( datacol );
+            return dataColumn;
 	}
 
 	/**
@@ -603,10 +624,61 @@ public class TreeView extends Container {
 		return new Type(gtk_tree_view_get_type());
 	}
 	
+    /**
+     * Enables or disables the fixed height mode of this TreeView. Fixed
+     * height mode speeds up TreeView by assuming that all rows
+     * have the same height. Only enable this option if all rows are
+     * the same height and all columns are of type
+     * {@link TreeViewColumnSizing#FIXED}.
+     *
+     * @param enable TRUE to enable fixed height mode.
+     */
+    public void setFixedHeightMode( boolean enable ) {
+        gtk_tree_view_set_fixed_height_mode( getHandle(), enable );
+    }
+    /**
+     * Returns whether fixed height mode is turned on for this TreeView.
+     */
+    public boolean getFixedHeightMode() {
+        return gtk_tree_view_get_fixed_height_mode( getHandle() );
+    }
+    /**
+     * Enables of disables the hover selection mode of this
+     * TreeView. Hover selection makes the selected row follow the
+     * pointer. Currently, this works only for the selection modes
+     * {@link SelectionMode#SINGLE} and {@link SelectionMode#BROWSE}.
+     *
+     * @param hover TRUE to enable hover selection mode.
+     */
+    public void setHoverSelection( boolean hover ) {
+        gtk_tree_view_set_hover_selection( getHandle(), hover );
+    }
+    /**
+     * Returns whether hover selection mode is turned on for this TreeView.
+     */
+    public boolean getHoverSelection() {
+        return gtk_tree_view_get_hover_selection( getHandle() );
+    }
+    /**
+     * Enables of disables the hover expansion mode of this
+     * TreeView. Hover expansion makes rows expand or collaps if the
+     * pointer moves over them.
+     *
+     * @param expand TRUE to enable hover selection mode.
+     */
+    public void setHoverExpand( boolean expand ) {
+        gtk_tree_view_set_hover_expand( getHandle(), expand );
+    }
+    /**
+     * Returns whether hover expansion mode is turned on for TreeView.
+     */
+    public boolean getHoverExpand() {
+        return gtk_tree_view_get_hover_expand( getHandle() );
+    }
 
-	/***************************************
-	 * Event Handler Related code
-	 ****************************************/
+    //
+    // Event Handler Related code
+    //
 
 	/**
 	 * Listeners for handling toggle events
@@ -626,7 +698,7 @@ public class TreeView extends Container {
 				evtMap.initialize(this, TreeViewEvent.Type.EXPAND_COLLAPSE_CURSOR_ROW);
 				evtMap.initialize(this, TreeViewEvent.Type.ROW_ACTIVATED);
 				evtMap.initialize(this, TreeViewEvent.Type.ROW_COLLAPSED);
-				evtMap.initialize(this, TreeViewEvent.Type.ROW_EXPANDED);
+				evtMap.initialize(this, TreeViewEvent.Type.ROW_COLLAPSED);
 				evtMap.initialize(this, TreeViewEvent.Type.SELECT_ALL);
 				evtMap.initialize(this, TreeViewEvent.Type.SELECT_CURSOR_PARENT);
 				evtMap.initialize(this, TreeViewEvent.Type.SELECT_CURSOR_ROW);
@@ -690,7 +762,7 @@ public class TreeView extends Container {
 		}
 	}
 
-	private void handleRowActivated(int path, int column) {
+	private void handleRowActivated(Handle path, Handle column) {
 		TreeViewEvent event = new TreeViewEvent(this, TreeViewEvent.Type.ROW_ACTIVATED);
 		event.setTreePath(new TreePath(path));
 		GObject obj = retrieveGObject(column);
@@ -701,14 +773,14 @@ public class TreeView extends Container {
 		fireTreeViewEvent(event);
 	}
 
-	private void handleRowExpanded(int iter, int path) {
+	private void handleRowExpanded(Handle iter, Handle path) {
 		TreeViewEvent event = new TreeViewEvent(this, TreeViewEvent.Type.ROW_EXPANDED);
 		event.setTreePath(new TreePath(path));
 		event.setTreeIter(new TreeIter(iter, getModel()));
 		fireTreeViewEvent(event);
 	}
 
-	private void handleRowCollapsed(int iter, int path) {
+	private void handleRowCollapsed(Handle iter, Handle path) {
 		TreeViewEvent event = new TreeViewEvent(this, TreeViewEvent.Type.ROW_COLLAPSED);
 		event.setTreePath(new TreePath(path));
 		event.setTreeIter(new TreeIter(iter, getModel()));
@@ -778,32 +850,6 @@ public class TreeView extends Container {
 		return et;
 	}
 
-	public PosInfo getPathAtPos(int x, int y) {
-	    int[] path = new int[1];
-	    int[] column = new int[1];
-	    int[] cellX = new int[1];
-	    int[] cellY = new int[1];
-	    if (gtk_tree_view_get_path_at_pos(getHandle(),x,y,path,column,cellX,cellY)) {
-	        PosInfo pos = new PosInfo(new TreePath(path[0]), new TreeViewColumn(column[0]), 
-	                cellX[0], cellY[0]);
-	        return pos;
-	    } else
-	        return null;
-	}
-	
-	public static class PosInfo {
-	    public int cellX;
-	    public int cellY;
-	    public TreePath path;
-	    public TreeViewColumn column;
-	    public PosInfo(TreePath path, TreeViewColumn column, int x, int y) {
-	        this.path = path;
-	        this.column = column;
-	        this.cellX = x;
-	        this.cellY = y;
-	    }
-	}
-	
 	private static EventMap evtMap = new EventMap();
 	static {
 		addEvents(evtMap);
@@ -828,50 +874,47 @@ public class TreeView extends Container {
 	}
 
 
-	/****************************************
-	 * BEGINNING OF JNI CODE
-	 ****************************************/
 	native static final protected int gtk_tree_view_get_type();
-	native static final protected int gtk_tree_view_new();
-	native static final protected int gtk_tree_view_new_with_model(int model);
-	native static final protected int gtk_tree_view_get_model(int treeView);
-	native static final protected void gtk_tree_view_set_model(int treeView, int model);
-	native static final protected int gtk_tree_view_get_selection(int treeView);
-	native static final protected int gtk_tree_view_get_hadjustment(int treeView);
-	native static final protected void gtk_tree_view_set_hadjustment(int treeView, int adjustment);
-	native static final protected int gtk_tree_view_get_vadjustment(int treeView);
-	native static final protected void gtk_tree_view_set_vadjustment(int treeView, int adjustment);
-	native static final protected boolean gtk_tree_view_get_headers_visible(int treeView);
-	native static final protected void gtk_tree_view_set_headers_visible(int treeView, boolean headersVisible);
-	native static final protected void gtk_tree_view_columns_autosize(int treeView);
-	native static final protected void gtk_tree_view_set_headers_clickable(int treeView, boolean setting);
-	native static final protected void gtk_tree_view_set_rules_hint(int treeView, boolean setting);
-	native static final protected boolean gtk_tree_view_get_rules_hint(int treeView);
-	native static final protected int gtk_tree_view_append_column(int treeView, int column);
-	native static final protected int gtk_tree_view_remove_column(int treeView, int column);
-	native static final protected int gtk_tree_view_insert_column(int treeView, int column, int position);
-	native static final protected int gtk_tree_view_get_column(int treeView, int n);
-	native static final protected int[] gtk_tree_view_get_columns(int treeView);
-	native static final protected void gtk_tree_view_move_column_after(int treeView, int column, int baseColumn);
-	native static final protected void gtk_tree_view_set_expander_column(int treeView, int column);
-	native static final protected int gtk_tree_view_get_expander_column(int treeView);
-	native static final protected void gtk_tree_view_scroll_to_point(int treeView, int treeX, int treeY);
-	native static final protected void gtk_tree_view_scroll_to_cell(int treeView, int path, int column, boolean useAlign, double rowAlign, double colAlign);
-	native static final protected void gtk_tree_view_row_activated(int treeView, int path, int column);
-	native static final protected void gtk_tree_view_expand_all(int treeView);
-	native static final protected void gtk_tree_view_collapse_all(int treeView);
-	native static final protected void gtk_tree_view_expand_to_path(int treeView, int path);
-	native static final protected boolean gtk_tree_view_expand_row(int treeView, int path, boolean openAll);
-	native static final protected boolean gtk_tree_view_collapse_row(int treeView, int path);
-	native static final protected boolean gtk_tree_view_row_expanded(int treeView, int path);
-	native static final protected void gtk_tree_view_set_reorderable(int treeView, boolean reorderable);
-	native static final protected boolean gtk_tree_view_get_reorderable(int treeView);
-	native static final protected void gtk_tree_view_set_cursor(int treeView, int path, int focusColumn, boolean startEditing);
-	native static final protected void gtk_tree_view_set_cursor_on_cell(int treeView, int path, int focusColumn, int focusCell, boolean startEditin);
-	native static final protected void gtk_tree_view_get_cursor(int treeView, int[] path, int[] focusColumn);
-//	native static final protected int gtk_tree_view_get_bin_window(int treeView);
-	native static final protected boolean gtk_tree_view_get_path_at_pos(int treeView, int x, int y, int[] path, int[] column, int[] cellX, int[] cellY);
-//	native static final protected int gtk_tree_view_get_cell_area(int treeView, int path, int column);
+	native static final protected Handle gtk_tree_view_new();
+	native static final protected Handle gtk_tree_view_new_with_model(Handle model);
+	native static final protected Handle gtk_tree_view_get_model(Handle treeView);
+	native static final protected void gtk_tree_view_set_model(Handle treeView, Handle model);
+	native static final protected Handle gtk_tree_view_get_selection(Handle treeView);
+	native static final protected Handle gtk_tree_view_get_hadjustment(Handle treeView);
+	native static final protected void gtk_tree_view_set_hadjustment(Handle treeView, Handle adjustment);
+	native static final protected Handle gtk_tree_view_get_vadjustment(Handle treeView);
+	native static final protected void gtk_tree_view_set_vadjustment(Handle treeView, Handle adjustment);
+	native static final protected boolean gtk_tree_view_get_headers_visible(Handle treeView);
+	native static final protected void gtk_tree_view_set_headers_visible(Handle treeView, boolean headersVisible);
+	native static final protected void gtk_tree_view_columns_autosize(Handle treeView);
+	native static final protected void gtk_tree_view_set_headers_clickable(Handle treeView, boolean setting);
+	native static final protected void gtk_tree_view_set_rules_hint(Handle treeView, boolean setting);
+	native static final protected boolean gtk_tree_view_get_rules_hint(Handle treeView);
+	native static final protected int gtk_tree_view_append_column(Handle treeView, Handle column);
+	native static final protected int gtk_tree_view_remove_column(Handle treeView, Handle column);
+	native static final protected int gtk_tree_view_insert_column(Handle treeView, Handle column, int position);
+	native static final protected Handle gtk_tree_view_get_column(Handle treeView, int n);
+	native static final protected Handle[] gtk_tree_view_get_columns(Handle treeView);
+	native static final protected void gtk_tree_view_move_column_after(Handle treeView, Handle column, Handle baseColumn);
+	native static final protected void gtk_tree_view_set_expander_column(Handle treeView, Handle column);
+	native static final protected Handle gtk_tree_view_get_expander_column(Handle treeView);
+	native static final protected void gtk_tree_view_scroll_to_point(Handle treeView, int treeX, int treeY);
+	native static final protected void gtk_tree_view_scroll_to_cell(Handle treeView, Handle path, Handle column, boolean useAlign, double rowAlign, double colAlign);
+	native static final protected void gtk_tree_view_row_activated(Handle treeView, Handle path, Handle column);
+	native static final protected void gtk_tree_view_expand_all(Handle treeView);
+	native static final protected void gtk_tree_view_collapse_all(Handle treeView);
+	native static final protected void gtk_tree_view_expand_to_path(Handle treeView, Handle path);
+	native static final protected boolean gtk_tree_view_expand_row(Handle treeView, Handle path, boolean openAll);
+	native static final protected boolean gtk_tree_view_collapse_row(Handle treeView, Handle path);
+	native static final protected boolean gtk_tree_view_row_expanded(Handle treeView, Handle path);
+	native static final protected void gtk_tree_view_set_reorderable(Handle treeView, boolean reorderable);
+	native static final protected boolean gtk_tree_view_get_reorderable(Handle treeView);
+	native static final protected void gtk_tree_view_set_cursor(Handle treeView, Handle path, Handle focusColumn, boolean startEditing);
+	native static final protected void gtk_tree_view_set_cursor_on_cell(Handle treeView, Handle path, Handle focusColumn, Handle focusCell, boolean startEditin);
+	native static final protected void gtk_tree_view_get_cursor(Handle treeView, Handle path, Handle focusColumn);
+	native static final protected Handle gtk_tree_view_get_bin_window(Handle treeView);
+	native static final protected boolean gtk_tree_view_get_path_at_pos(Handle treeView, int x, int y, Handle path, Handle column, int cellX, int cellY);
+    //	native static final protected int gtk_tree_view_get_cell_area(int treeView, int path, int column);
 //	native static final protected int gtk_tree_view_get_background_area(int treeView, int path, int column);
 //	native static final protected int gtk_tree_view_get_visible_rect(int treeView);
 //	native static final protected void gtk_tree_view_widget_to_tree_coords(int treeView, int wx, int wy, int[] tx, int[] ty);
@@ -881,11 +924,19 @@ public class TreeView extends Container {
 //	native static final protected void gtk_tree_view_unset_rows_drag_source(int treeView);
 //	native static final protected void gtk_tree_view_unset_rows_drag_dest(int treeView);
 //	native static final protected int gtk_tree_view_create_row_drag_icon(int treeView, int path);
-	native static final protected void gtk_tree_view_set_enable_search(int treeView, boolean enableSearch);
-	native static final protected boolean gtk_tree_view_get_enable_search(int treeView);
-	native static final protected int gtk_tree_view_get_search_column(int treeView);
-	native static final protected void gtk_tree_view_set_search_column(int treeView, int column);
-	/****************************************
-	 * END OF JNI CODE
-	 ****************************************/
+	native static final protected void gtk_tree_view_set_enable_search(Handle treeView, boolean enableSearch);
+	native static final protected boolean gtk_tree_view_get_enable_search(Handle treeView);
+	native static final protected int gtk_tree_view_get_search_column(Handle treeView);
+	native static final protected void gtk_tree_view_set_search_column(Handle treeView, int dataColumn);
+
+    // GTK 2.6 additions.
+    native static final private void gtk_tree_view_set_fixed_height_mode(Handle tree_view, boolean enable);
+    native static final private boolean gtk_tree_view_get_fixed_height_mode(Handle tree_view);
+    native static final private void gtk_tree_view_set_hover_selection(Handle tree_view, boolean hover);
+    native static final private boolean gtk_tree_view_get_hover_selection(Handle tree_view);
+    native static final private void gtk_tree_view_set_hover_expand(Handle tree_view, boolean expand);
+    native static final private boolean gtk_tree_view_get_hover_expand(Handle tree_view);
+    //native static final private int gtk_tree_view_get_row_separator_func(Handle tree_view);
+    //native static final private void gtk_tree_view_set_row_separator_func(Handle tree_view, int func, gpointer data, int destroy);
+
 }
