@@ -9,6 +9,8 @@
 
 package org.gnu.pango;
 
+import org.gnu.glib.Handle;
+
 
 /**
  * The AttrShape structure is used to represent attributes which impose shape restrictions.
@@ -32,8 +34,8 @@ public class AttrShape extends Attribute
     /****************************************
      * BEGINNING OF GENERATED CODE
      ****************************************/
-    native static final protected int getInkRect (int obj);
-    native static final protected int getLogicalRect (int obj);
+    native static final protected Handle getInkRect (Handle obj);
+    native static final protected Handle getLogicalRect (Handle obj);
     /****************************************
      * END OF GENERATED CODE
      ****************************************/
