@@ -17,152 +17,152 @@ extern "C"
 {
 #endif
 
-///*
-// * Class:     org.gnu.gdk.Pixbuf
-// * Method:    gdk_pixbuf_render_threshold_alpha
-// */
-//JNIEXPORT void JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1render_1threshold_1alpha (JNIEnv 
-//    *env, jclass cls, jobject pixbuf, jobject bitmap, jint srcX, jint srcY, jint destX, jint destY, 
-//    jint width, jint height, jint alphaThreshold) 
-//{
-//    GdkPixbuf *pixbuf_g = (GdkPixbuf *)getPointerFromHandle(env, pixbuf);
-//    GdkBitmap *bitmap_g = (GdkBitmap *)getPointerFromHandle(env, bitmap);
-//    gint32 srcX_g = (gint32) srcX;
-//    gint32 srcY_g = (gint32) srcY;
-//    gint32 destX_g = (gint32) destX;
-//    gint32 destY_g = (gint32) destY;
-//    gint32 width_g = (gint32) width;
-//    gint32 height_g = (gint32) height;
-//    gint32 alphaThreshold_g = (gint32) alphaThreshold;
-//    gdk_pixbuf_render_threshold_alpha (pixbuf_g, bitmap_g, srcX_g, srcY_g, destX_g, 
-//            destY_g, width_g, height_g, alphaThreshold_g);
-//}
-//
-///*
-// * Class:     org.gnu.gdk.Pixbuf
-// * Method:    gdk_pixbuf_render_to_drawable
-// */
-//JNIEXPORT void JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1render_1to_1drawable (JNIEnv *env, 
-//    jclass cls, jobject pixbuf, jobject drawable, jobject gc, jint srcX, jint srcY, jint destX, jint 
-//    destY, jint width, jint height, jint dither, jint xDither, jint yDither) 
-//{
-//    GdkPixbuf *pixbuf_g = (GdkPixbuf *)getPointerFromHandle(env, pixbuf);
-//    GdkDrawable *drawable_g = (GdkDrawable *)getPointerFromHandle(env, drawable);
-//    GdkGC *gc_g = (GdkGC *)getPointerFromHandle(env, gc);
-//    gint32 srcX_g = (gint32) srcX;
-//    gint32 srcY_g = (gint32) srcY;
-//    gint32 destX_g = (gint32) destX;
-//    gint32 destY_g = (gint32) destY;
-//    gint32 width_g = (gint32) width;
-//    gint32 height_g = (gint32) height;
-//    GdkRgbDither dither_g = (GdkRgbDither) dither;
-//    gint32 xDither_g = (gint32) xDither;
-//    gint32 yDither_g = (gint32) yDither;
-//    gdk_pixbuf_render_to_drawable (pixbuf_g, drawable_g, gc_g, srcX_g, srcY_g, destX_g, 
-//            destY_g, width_g, height_g, dither_g, xDither_g, yDither_g);
-//}
-//
-///*
-// * Class:     org.gnu.gdk.Pixbuf
-// * Method:    gdk_pixbuf_render_to_drawable_alpha
-// */
-//JNIEXPORT void JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1render_1to_1drawable_1alpha (JNIEnv 
-//    *env, jclass cls, jobject pixbuf, jobject drawable, jint srcX, jint srcY, jint destX, jint destY, 
-//    jint width, jint height, jint alphaMode, jint alphaThreshold, jint dither, jint xDither, 
-//    jint yDither) 
-//{
-//    GdkPixbuf *pixbuf_g = (GdkPixbuf *)getPointerFromHandle(env, pixbuf);
-//    GdkDrawable *drawable_g = (GdkDrawable *)getPointerFromHandle(env, drawable);
-//    gint32 srcX_g = (gint32) srcX;
-//    gint32 srcY_g = (gint32) srcY;
-//    gint32 destX_g = (gint32) destX;
-//    gint32 destY_g = (gint32) destY;
-//    gint32 width_g = (gint32) width;
-//    gint32 height_g = (gint32) height;
-//    GdkPixbufAlphaMode alphaMode_g = (GdkPixbufAlphaMode) alphaMode;
-//    gint32 alphaThreshold_g = (gint32) alphaThreshold;
-//    GdkRgbDither dither_g = (GdkRgbDither) dither;
-//    gint32 xDither_g = (gint32) xDither;
-//    gint32 yDither_g = (gint32) yDither;
-//    gdk_pixbuf_render_to_drawable_alpha (pixbuf_g, drawable_g, srcX_g, srcY_g, destX_g, 
-//            destY_g, width_g, height_g, alphaMode_g, alphaThreshold_g, dither_g, xDither_g, 
-//            yDither_g);
-//}
-//
-///*
-// * Class:     org.gnu.gdk.Pixbuf
-// * Method:    gdk_pixbuf_render_pixmap_and_mask_for_colormap
-// */
-//JNIEXPORT void JNICALL 
-//Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1render_1pixmap_1and_1mask_1for_1colormap (JNIEnv *env, 
-//    jclass cls, jobject pixbuf, jobject colormap, jobject pixmapReturn, jobject maskReturn, jint 
-//    alphaThreshold) 
-//{
-//    GdkPixbuf *pixbuf_g = (GdkPixbuf *)getPointerFromHandle(env, pixbuf);
-//    GdkColormap *colormap_g = (GdkColormap *)getPointerFromHandle(env, colormap);
-//    GdkPixmap **pixmapReturn_g = (GdkPixmap **)getPointerFromHandle(env, pixmapReturn);
-//    GdkBitmap **maskReturn_g = (GdkBitmap **)getPointerFromHandle(env, maskReturn);
-//    gint32 alphaThreshold_g = (gint32) alphaThreshold;
-//    gdk_pixbuf_render_pixmap_and_mask_for_colormap (pixbuf_g, colormap_g, pixmapReturn_g, 
-//            maskReturn_g, alphaThreshold_g);
-//}
-//
-///*
-// * Class:     org.gnu.gdk.Pixbuf
-// * Method:    gdk_pixbuf_render_pixmap_and_mask
-// */
-//JNIEXPORT void JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1render_1pixmap_1and_1mask (JNIEnv 
-//    *env, jclass cls, jobject pixbuf, jobject pixmapReturn, jobject maskReturn, jint alphaThreshold) 
-//{
-//    GdkPixbuf *pixbuf_g = (GdkPixbuf *)getPointerFromHandle(env, pixbuf);
-//    GdkPixmap **pixmapReturn_g = (GdkPixmap **)getPointerFromHandle(env, pixmapReturn);
-//    GdkBitmap **maskReturn_g = (GdkBitmap **)getPointerFromHandle(env, maskReturn);
-//    gint32 alphaThreshold_g = (gint32) alphaThreshold;
-//    gdk_pixbuf_render_pixmap_and_mask (pixbuf_g, pixmapReturn_g, maskReturn_g, 
-//            alphaThreshold_g);
-//}
-//
-///*
-// * Class:     org.gnu.gdk.Pixbuf
-// * Method:    gdk_pixbuf_get_from_drawable
-// */
-//JNIEXPORT jobject JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1get_1from_1drawable (JNIEnv *env, 
-//    jclass cls, jobject dest, jobject src, jobject cmap, jint srcX, jint srcY, jint destX, jint destY, 
-//    jint width, jint height) 
-//{
-//    GdkPixbuf *dest_g = (GdkPixbuf *)getPointerFromHandle(env, dest);
-//    GdkDrawable *src_g = (GdkDrawable *)getPointerFromHandle(env, src);
-//    GdkColormap *cmap_g = (GdkColormap *)getPointerFromHandle(env, cmap);
-//    gint32 srcX_g = (gint32) srcX;
-//    gint32 srcY_g = (gint32) srcY;
-//    gint32 destX_g = (gint32) destX;
-//    gint32 destY_g = (gint32) destY;
-//    gint32 width_g = (gint32) width;
-//    gint32 height_g = (gint32) height;
-//    return getHandleFromPointer(env, gdk_pixbuf_get_from_drawable (dest_g, src_g, cmap_g, srcX_g, srcY_g, 
-//            destX_g, destY_g, width_g, height_g));
-//}
-//
-///*
-// * Class:     org.gnu.gdk.Pixbuf
-// * Method:    gdk_pixbuf_get_from_image
-// */
-//JNIEXPORT jobject JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1get_1from_1image (JNIEnv *env, 
-//    jclass cls, jobject dest, jobject src, jobject cmap, jint srcX, jint srcY, jint destX, jint destY, 
-//    jint width, jint height) 
-//{
-//    GdkPixbuf *dest_g = (GdkPixbuf *)getPointerFromHandle(env, dest);
-//    GdkImage *src_g = (GdkImage *)getPointerFromHandle(env, src);
-//    GdkColormap *cmap_g = (GdkColormap *)getPointerFromHandle(env, cmap);
-//    gint32 srcX_g = (gint32) srcX;
-//    gint32 srcY_g = (gint32) srcY;
-//    gint32 destX_g = (gint32) destX;
-//    gint32 destY_g = (gint32) destY;
-//    gint32 width_g = (gint32) width;
-//    gint32 height_g = (gint32) height;
-//    return getHandleFromPointer(env, gdk_pixbuf_get_from_image (dest_g, src_g, cmap_g, srcX_g, srcY_g, destX_g, 
-//            destY_g, width_g, height_g));
-//}
+/*
+ * Class:     org.gnu.gdk.Pixbuf
+ * Method:    gdk_pixbuf_render_threshold_alpha
+ */
+JNIEXPORT void JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1render_1threshold_1alpha (JNIEnv 
+    *env, jclass cls, jobject pixbuf, jobject bitmap, jint srcX, jint srcY, jint destX, jint destY, 
+    jint width, jint height, jint alphaThreshold) 
+{
+    GdkPixbuf *pixbuf_g = (GdkPixbuf *)getPointerFromHandle(env, pixbuf);
+    GdkBitmap *bitmap_g = (GdkBitmap *)getPointerFromHandle(env, bitmap);
+    gint32 srcX_g = (gint32) srcX;
+    gint32 srcY_g = (gint32) srcY;
+    gint32 destX_g = (gint32) destX;
+    gint32 destY_g = (gint32) destY;
+    gint32 width_g = (gint32) width;
+    gint32 height_g = (gint32) height;
+    gint32 alphaThreshold_g = (gint32) alphaThreshold;
+    gdk_pixbuf_render_threshold_alpha (pixbuf_g, bitmap_g, srcX_g, srcY_g, destX_g, 
+            destY_g, width_g, height_g, alphaThreshold_g);
+}
+
+/*
+ * Class:     org.gnu.gdk.Pixbuf
+ * Method:    gdk_pixbuf_render_to_drawable
+ */
+JNIEXPORT void JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1render_1to_1drawable (JNIEnv *env, 
+    jclass cls, jobject pixbuf, jobject drawable, jobject gc, jint srcX, jint srcY, jint destX, jint 
+    destY, jint width, jint height, jint dither, jint xDither, jint yDither) 
+{
+    GdkPixbuf *pixbuf_g = (GdkPixbuf *)getPointerFromHandle(env, pixbuf);
+    GdkDrawable *drawable_g = (GdkDrawable *)getPointerFromHandle(env, drawable);
+    GdkGC *gc_g = (GdkGC *)getPointerFromHandle(env, gc);
+    gint32 srcX_g = (gint32) srcX;
+    gint32 srcY_g = (gint32) srcY;
+    gint32 destX_g = (gint32) destX;
+    gint32 destY_g = (gint32) destY;
+    gint32 width_g = (gint32) width;
+    gint32 height_g = (gint32) height;
+    GdkRgbDither dither_g = (GdkRgbDither) dither;
+    gint32 xDither_g = (gint32) xDither;
+    gint32 yDither_g = (gint32) yDither;
+    gdk_pixbuf_render_to_drawable (pixbuf_g, drawable_g, gc_g, srcX_g, srcY_g, destX_g, 
+            destY_g, width_g, height_g, dither_g, xDither_g, yDither_g);
+}
+
+/*
+ * Class:     org.gnu.gdk.Pixbuf
+ * Method:    gdk_pixbuf_render_to_drawable_alpha
+ */
+JNIEXPORT void JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1render_1to_1drawable_1alpha (JNIEnv 
+    *env, jclass cls, jobject pixbuf, jobject drawable, jint srcX, jint srcY, jint destX, jint destY, 
+    jint width, jint height, jint alphaMode, jint alphaThreshold, jint dither, jint xDither, 
+    jint yDither) 
+{
+    GdkPixbuf *pixbuf_g = (GdkPixbuf *)getPointerFromHandle(env, pixbuf);
+    GdkDrawable *drawable_g = (GdkDrawable *)getPointerFromHandle(env, drawable);
+    gint32 srcX_g = (gint32) srcX;
+    gint32 srcY_g = (gint32) srcY;
+    gint32 destX_g = (gint32) destX;
+    gint32 destY_g = (gint32) destY;
+    gint32 width_g = (gint32) width;
+    gint32 height_g = (gint32) height;
+    GdkPixbufAlphaMode alphaMode_g = (GdkPixbufAlphaMode) alphaMode;
+    gint32 alphaThreshold_g = (gint32) alphaThreshold;
+    GdkRgbDither dither_g = (GdkRgbDither) dither;
+    gint32 xDither_g = (gint32) xDither;
+    gint32 yDither_g = (gint32) yDither;
+    gdk_pixbuf_render_to_drawable_alpha (pixbuf_g, drawable_g, srcX_g, srcY_g, destX_g, 
+            destY_g, width_g, height_g, alphaMode_g, alphaThreshold_g, dither_g, xDither_g, 
+            yDither_g);
+}
+
+/*
+ * Class:     org.gnu.gdk.Pixbuf
+ * Method:    gdk_pixbuf_render_pixmap_and_mask_for_colormap
+ */
+JNIEXPORT void JNICALL 
+Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1render_1pixmap_1and_1mask_1for_1colormap (JNIEnv *env, 
+    jclass cls, jobject pixbuf, jobject colormap, jobject pixmapReturn, jobject maskReturn, jint 
+    alphaThreshold) 
+{
+    GdkPixbuf *pixbuf_g = (GdkPixbuf *)getPointerFromHandle(env, pixbuf);
+    GdkColormap *colormap_g = (GdkColormap *)getPointerFromHandle(env, colormap);
+    GdkPixmap **pixmapReturn_g = (GdkPixmap **)getPointerFromHandle(env, pixmapReturn);
+    GdkBitmap **maskReturn_g = (GdkBitmap **)getPointerFromHandle(env, maskReturn);
+    gint32 alphaThreshold_g = (gint32) alphaThreshold;
+    gdk_pixbuf_render_pixmap_and_mask_for_colormap (pixbuf_g, colormap_g, pixmapReturn_g, 
+            maskReturn_g, alphaThreshold_g);
+}
+
+/*
+ * Class:     org.gnu.gdk.Pixbuf
+ * Method:    gdk_pixbuf_render_pixmap_and_mask
+ */
+JNIEXPORT void JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1render_1pixmap_1and_1mask (JNIEnv 
+    *env, jclass cls, jobject pixbuf, jobject pixmapReturn, jobject maskReturn, jint alphaThreshold) 
+{
+    GdkPixbuf *pixbuf_g = (GdkPixbuf *)getPointerFromHandle(env, pixbuf);
+    GdkPixmap **pixmapReturn_g = (GdkPixmap **)getPointerFromHandle(env, pixmapReturn);
+    GdkBitmap **maskReturn_g = (GdkBitmap **)getPointerFromHandle(env, maskReturn);
+    gint32 alphaThreshold_g = (gint32) alphaThreshold;
+    gdk_pixbuf_render_pixmap_and_mask (pixbuf_g, pixmapReturn_g, maskReturn_g, 
+            alphaThreshold_g);
+}
+
+/*
+ * Class:     org.gnu.gdk.Pixbuf
+ * Method:    gdk_pixbuf_get_from_drawable
+ */
+JNIEXPORT jobject JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1get_1from_1drawable (JNIEnv *env, 
+    jclass cls, jobject dest, jobject src, jobject cmap, jint srcX, jint srcY, jint destX, jint destY, 
+    jint width, jint height) 
+{
+    GdkPixbuf *dest_g = (GdkPixbuf *)getPointerFromHandle(env, dest);
+    GdkDrawable *src_g = (GdkDrawable *)getPointerFromHandle(env, src);
+    GdkColormap *cmap_g = (GdkColormap *)getPointerFromHandle(env, cmap);
+    gint32 srcX_g = (gint32) srcX;
+    gint32 srcY_g = (gint32) srcY;
+    gint32 destX_g = (gint32) destX;
+    gint32 destY_g = (gint32) destY;
+    gint32 width_g = (gint32) width;
+    gint32 height_g = (gint32) height;
+    return getHandleFromPointer(env, gdk_pixbuf_get_from_drawable (dest_g, src_g, cmap_g, srcX_g, srcY_g, 
+            destX_g, destY_g, width_g, height_g));
+}
+
+/*
+ * Class:     org.gnu.gdk.Pixbuf
+ * Method:    gdk_pixbuf_get_from_image
+ */
+JNIEXPORT jobject JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1get_1from_1image (JNIEnv *env, 
+    jclass cls, jobject dest, jobject src, jobject cmap, jint srcX, jint srcY, jint destX, jint destY, 
+    jint width, jint height) 
+{
+    GdkPixbuf *dest_g = (GdkPixbuf *)getPointerFromHandle(env, dest);
+    GdkImage *src_g = (GdkImage *)getPointerFromHandle(env, src);
+    GdkColormap *cmap_g = (GdkColormap *)getPointerFromHandle(env, cmap);
+    gint32 srcX_g = (gint32) srcX;
+    gint32 srcY_g = (gint32) srcY;
+    gint32 destX_g = (gint32) destX;
+    gint32 destY_g = (gint32) destY;
+    gint32 width_g = (gint32) width;
+    gint32 height_g = (gint32) height;
+    return getHandleFromPointer(env, gdk_pixbuf_get_from_image (dest_g, src_g, cmap_g, srcX_g, srcY_g, destX_g, 
+            destY_g, width_g, height_g));
+}
 
 /*
  * Class:     org.gnu.gdk.Pixbuf
@@ -277,7 +277,8 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1new (JNIEnv *env,
  * Class:     org.gnu.gdk.Pixbuf
  * Method:    gdk_pixbuf_copy
  */
-JNIEXPORT jobject JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1copy (JNIEnv *env, jclass cls, jobject pixbuf) 
+JNIEXPORT jobject JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1copy (JNIEnv *env, jclass cls, jobject 
+    pixbuf) 
 {
     GdkPixbuf *pixbuf_g = (GdkPixbuf *)getPointerFromHandle(env, pixbuf);
     return getHandleFromPointer(env, gdk_pixbuf_copy (pixbuf_g));
@@ -304,51 +305,14 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1new_1subpixbuf (J
  * Method:    gdk_pixbuf_new_from_file
  */
 JNIEXPORT jobject JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1new_1from_1file (JNIEnv *env, 
-    jclass cls, jstring filename, jobject error) 
+    jclass cls, jstring filename, jint error) 
 {
     const gchar* filename_g = (*env)->GetStringUTFChars(env, filename, 0);
-    GError* error_g = NULL;
-    jobject result =  getHandleFromPointer(env, gdk_pixbuf_new_from_file (filename_g, &error_g));
+    jobject result =  getHandleFromPointer(env, gdk_pixbuf_new_from_file (filename_g, (GError**)error));
     (*env)->ReleaseStringUTFChars(env, filename, filename_g);
-    if (NULL != error_g)
-    	updateHandle(env, error, error_g);
     return result;
 }
 
-/*
- * Class:     org_gnu_gdk_Pixbuf
- * Method:    gdk_pixbuf_new_from_file_at_size
- */
-JNIEXPORT jobject JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1new_1from_1file_1at_1size
-  (JNIEnv *env, jclass cls, jstring filename, jint width, jint height, jobject error)
-{
-    const gchar* filename_g = (*env)->GetStringUTFChars(env, filename, 0);
-    GError* error_g = NULL;
-    jobject result =  getHandleFromPointer(env, gdk_pixbuf_new_from_file_at_size (filename_g, width, height, &error_g));
-    (*env)->ReleaseStringUTFChars(env, filename, filename_g);
-    if (NULL != error_g)
-    	updateHandle(env, error, error_g);
-    return result;
-}
-
-/*
- * Class:     org_gnu_gdk_Pixbuf
- * Method:    gdk_pixbuf_get_file_info
- */
-JNIEXPORT jobject JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1get_1file_1info
-  (JNIEnv *env, jclass cls, jstring filename, jintArray width, jintArray height)
-{
-    const gchar* filename_g = (*env)->GetStringUTFChars(env, filename, 0);
-	gint* w = (gint*)(*env)->GetIntArrayElements(env, width, NULL);
-	gint* h = (gint*)(*env)->GetIntArrayElements(env, height, NULL);
-	jobject handle = getHandleFromPointer(env, gdk_pixbuf_get_file_info(filename_g, w, h));
-	(*env)->ReleaseIntArrayElements(env, width, (jint*)w, 0);
-	(*env)->ReleaseIntArrayElements(env, height, (jint*)h, 0);
-	return handle;
-}
-
-
-
 /*
  * Class:     org.gnu.gdk.Pixbuf
  * Method:    gdk_pixbuf_new_from_xpm_data
@@ -368,67 +332,16 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1new_1from_1xpm_1d
  * Method:    gdk_pixbuf_new_from_inline
  */
 JNIEXPORT jobject JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1new_1from_1inline (JNIEnv *env, 
-    jclass cls, jint dataLength, jbyteArray data, jboolean copyPixels, jobject error) 
+    jclass cls, jint dataLength, jbyteArray data, jboolean copyPixels, jint error) 
 {
     gint32 dataLength_g = (gint32) dataLength;
     jint data_len = (*env)->GetArrayLength(env, data);
     gchar* data_g = (gchar*)g_malloc(data_len + 1);
     gboolean copyPixels_g = (gboolean) copyPixels;
-    GError* error_g = NULL;
+    GError **error_g = (GError **)error;
     (*env)->GetByteArrayRegion(env, data, 0, data_len, (jbyte*)data_g);
     data_g[data_len] = 0;
-    jobject handle = getHandleFromPointer(env,
-    	gdk_pixbuf_new_from_inline (dataLength_g, data_g, copyPixels_g, &error_g));
-    if (NULL != error_g)
-    	updateHandle(env, error, error_g);
-    return handle;
-}
-
-/*
- * Class:     org_gnu_gdk_Pixbuf
- * Method:    gdk_pixbuf_savev
- */
-JNIEXPORT jboolean JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1savev
-  (JNIEnv *env, jclass cls, jobject pixbuf, jstring filename, jstring type, jobjectArray keys, jobjectArray values, jobject error)
-{
-    GdkPixbuf *pixbuf_g = (GdkPixbuf *)getPointerFromHandle(env, pixbuf);
-    const gchar* f = (*env)->GetStringUTFChars(env, filename, NULL);
-    const gchar* t = (*env)->GetStringUTFChars(env, type, NULL);
-    gchar** k = getStringArray(env, keys);
-    gchar** v = getStringArray(env, values);
-    GError* error_g = NULL;
-	jboolean val = gdk_pixbuf_savev(pixbuf_g, f, t, k, v, &error_g);
-    if (NULL != error_g)
-    	updateHandle(env, error, error_g);
-	(*env)->ReleaseStringUTFChars(env, filename, f);
-	(*env)->ReleaseStringUTFChars(env, type, t);
-	freeStringArray(env, keys, k);
-	freeStringArray(env, values, v);
-	return val;	
-}
-
-/*
- * Class:     org_gnu_gdk_Pixbuf
- * Method:    gdk_pixbuf_save_to_bufferv
- */
-JNIEXPORT jboolean JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1save_1to_1bufferv
-  (JNIEnv *env, jclass cls, jobject pixbuf, jstring buffer, jstring type, jobjectArray keys, jobjectArray values, jobject error)
-{
-    GdkPixbuf *pixbuf_g = (GdkPixbuf *)getPointerFromHandle(env, pixbuf);
-    gchar* b = (gchar*)(*env)->GetStringUTFChars(env, buffer, NULL);
-    const gchar* t = (*env)->GetStringUTFChars(env, type, NULL);
-    gchar** k = getStringArray(env, keys);
-    gchar** v = getStringArray(env, values);
-    GError* error_g = NULL;
-    gsize size;
-	jboolean val = gdk_pixbuf_save_to_bufferv(pixbuf_g, &b, &size, t, k, v, &error_g);
-    if (NULL != error_g)
-    	updateHandle(env, error, error_g);
-	(*env)->ReleaseStringUTFChars(env, buffer, b);
-	(*env)->ReleaseStringUTFChars(env, type, t);
-	freeStringArray(env, keys, k);
-	freeStringArray(env, values, v);
-	return val;
+    return getHandleFromPointer(env, gdk_pixbuf_new_from_inline (dataLength_g, data_g, copyPixels_g, error_g));
 }
 
 /*
@@ -447,7 +360,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1fill (JNIEnv *env, j
  * Class:     org.gnu.gdk.Pixbuf
  * Method:    gdk_pixbuf_add_alpha
  */
-JNIEXPORT jobject JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1add_1alpha (JNIEnv *env, jclass 
+JNIEXPORT jint JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1add_1alpha (JNIEnv *env, jclass 
     cls, jobject pixbuf, jboolean substituteColor, jint r, jint g, jint b) 
 {
     GdkPixbuf *pixbuf_g = (GdkPixbuf *)getPointerFromHandle(env, pixbuf);
@@ -455,8 +368,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1add_1alpha (JNIEn
     gint32 r_g = (gint32) r;
     gint32 g_g = (gint32) g;
     gint32 b_g = (gint32) b;
-    return getHandleFromPointer(env,
-    		gdk_pixbuf_add_alpha (pixbuf_g, substituteColor_g, r_g, g_g, b_g));
+    return (jint)gdk_pixbuf_add_alpha (pixbuf_g, substituteColor_g, r_g, g_g, b_g);
 }
 
 /*
