@@ -9,32 +9,14 @@
 
 #include <jni.h>
 #include <string.h>
-#include <sys/types.h>
 #include <glib.h>
 #include <glib-object.h>
+#include "jg_jnu.h"
 #ifdef __cplusplus
 extern "C" 
 {
 #endif
 
-static jfieldID gtkobj_fieldID = NULL;
-
-#define JGTKO(x) jobject_to_gtk(env, x)
-
-/* Given a Java object, this method gets the native GtkObject object */
-GObject *
-jobject_to_gtk(JNIEnv *env, jobject obj)
-{
-  jint obj_pointer;
-
-//  if(!gtkobj_fieldID)
-    gtkobj_fieldID = (*env)->GetFieldID(env, (*env)->GetObjectClass(env, obj), 
-					"handle", "I");
-  obj_pointer = (*env)->GetIntField(env, obj, gtkobj_fieldID);
-  
-  return G_OBJECT((void *)obj_pointer);
-}
-
 typedef struct {
   JNIEnv *env;
   jobject obj;  /* object to recieve the signal */
@@ -89,6 +71,12 @@ javatype_from_gtktype(GType argtype)
       tmp = &tmp[3];
     sprintf(javatype, "org/gnu/atk/%s", tmp);
   }
+  else if (strncmp(tmp, "Html", 4) == 0) {
+    sprintf(javatype, "org/gnu/gtkhtml/%s", tmp);
+  }
+  else if (strncmp(tmp, "Dom", 3) == 0) {
+    sprintf(javatype, "org/gnu/gtkhtml/dom/%s", tmp);
+  }
   else
     sprintf(javatype, "%s", tmp);
 
@@ -114,7 +102,7 @@ jg_signal_cb(GClosure *closure,
   jmethodID mid;
   jclass clazz;
   jobject localObj;
-  jint peer;
+  jobject peer;
   jfieldID peerfid;
   jthrowable exc;
   gboolean b;
@@ -178,26 +166,26 @@ jg_signal_cb(GClosure *closure,
       jargs[i-1].l = localObj;
       break;
     case G_TYPE_BOXED:
-      peer = (jint)g_value_get_boxed(&param_values[i]);
-      jargs[i-1].i = peer;
+      peer = getHandleFromPointer(cbdata->env, g_value_get_boxed(&param_values[i]));
+      jargs[i-1].l = peer;
       break;
     case G_TYPE_POINTER:
-      peer = (jint)g_value_get_pointer(&param_values[i]);
-      jargs[i-1].i = peer;
+      peer = getHandleFromPointer(cbdata->env, g_value_get_pointer(&param_values[i]));
+      jargs[i-1].l = peer;
       break;
     default:
       jtype = javatype_from_gtktype(G_VALUE_TYPE(&param_values[i]));
       clazz = (* cbdata->env)->FindClass(cbdata->env, jtype);
       g_free((gpointer)jtype);
-      
       if (clazz == NULL) {
-	return;
+		return;
       }
+    
       localObj = (* cbdata->env)->AllocObject(cbdata->env, clazz);
-      *(void **) &peer = g_value_get_object(&param_values[i]);
+      peer = getHandleFromPointer(cbdata->env, g_value_get_object(&param_values[i]));
       peerfid = (* cbdata->env)->GetFieldID(cbdata->env, clazz, 
-					    "handle", "I");
-      (* cbdata->env)->SetIntField(cbdata->env, localObj, peerfid, peer);
+					    "handle", "Lorg/gnu/glib/Handle");
+      (* cbdata->env)->SetObjectField(cbdata->env, localObj, peerfid, peer);
       jargs[i-1].l = localObj;
       break;
     }
@@ -401,7 +389,8 @@ jg_cbdata_new(JNIEnv *env,
   jthrowable exc;
   jclass Exception;
   
-  gtko = JGTKO(obj);
+  //  gtko = (GObject*)getPointerFromHandle(env, obj);
+  gtko = (GObject*)getPointerFromJavaGObject(env, obj);
   sigid = g_signal_lookup(signame, G_OBJECT_TYPE(gtko));
   g_assert(sigid > 0);
   g_signal_query(sigid, &siginfo);
@@ -466,7 +455,7 @@ jg_static_cbdata_new(JNIEnv *env,
   jthrowable exc;
   jclass Exception;
   
-  gtko = JGTKO(obj);
+  gtko = (GObject*)getPointerFromHandle(env, obj);
   sigid = g_signal_lookup(signame, G_OBJECT_TYPE(gtko));
   g_assert(sigid > 0);
   g_signal_query(sigid, &siginfo);
@@ -527,10 +516,14 @@ static jint create_callback(JNIEnv *env,
 
   jclass Exception;
 
-  go = JGTKO(obj);
+//  go = (GObject*)getPointerFromHandle(env, obj);
+  go = (GObject*)getPointerFromJavaGObject(env, obj);
+  if (go == NULL)
+  	printf("go is NULL\n");
   signame = (*env)->GetStringUTFChars(env, sigstring, NULL);
   sigfunc = (*env)->GetStringUTFChars(env, func, NULL);
   
+
   if (!g_signal_parse_name(signame, G_OBJECT_TYPE(go),
 			   &sigid, &detail, TRUE)) {
     g_critical("Java-GNOME - unknown signal name %s, function %s, object %s.\n", signame, sigfunc, G_OBJECT_TYPE_NAME(go));
@@ -538,7 +531,6 @@ static jint create_callback(JNIEnv *env,
     (* env)->ThrowNew(env, Exception, "" );
     return 0;
   }
-
   cbdata = jg_cbdata_new(env, obj, cbrecv, data, signame, sigfunc);
 
   if (cbdata == NULL)
@@ -547,7 +539,8 @@ static jint create_callback(JNIEnv *env,
   closure = jg_closure_new();
   ((JGClosure *)closure)->cbdata = cbdata;
 
-  retval = g_signal_connect_closure_by_id(JGTKO(obj),
+  //retval = g_signal_connect_closure_by_id(getPointerFromHandle(env, obj),
+  retval = g_signal_connect_closure_by_id(getPointerFromJavaGObject(env, obj),
 					  sigid,
 					  detail,
 					  closure,
@@ -555,7 +548,6 @@ static jint create_callback(JNIEnv *env,
 
   (*env)->ReleaseStringUTFChars(env, sigstring, signame);
   (*env)->ReleaseStringUTFChars(env, func, sigfunc);
-    
   return retval;
 }
 
@@ -577,7 +569,7 @@ static jint create_static_callback(JNIEnv *env,
   GClosure *closure;
   jclass Exception;
   
-  go = JGTKO(obj);
+  go = (GObject*)getPointerFromHandle(env, obj);
   signame = (*env)->GetStringUTFChars(env, sigstring, NULL);
   sigfunc = (*env)->GetStringUTFChars(env, func, NULL);
   
@@ -596,7 +588,7 @@ static jint create_static_callback(JNIEnv *env,
     
   closure = jg_closure_new();
   ((JGClosure *)closure)->cbdata = cbdata;
-  retval = g_signal_connect_closure_by_id(JGTKO(obj),
+  retval = g_signal_connect_closure_by_id(getPointerFromHandle(env, obj),
 					  sigid,
 					  detail,
 					  closure,
@@ -630,7 +622,7 @@ JNIEXPORT jint JNICALL
 Java_org_gnu_glib_GObject_addEventHandler__Ljava_lang_String_2Ljava_lang_String_2Ljava_lang_Object_2 
 (JNIEnv *env, jobject obj, jstring sigstring, jstring func, jobject cbrecv)
 { 
-  return create_callback(env, obj, sigstring, func, cbrecv, NULL);
+	return create_callback(env, obj, sigstring, func, cbrecv, NULL);
 }
 
 
@@ -694,7 +686,7 @@ Java_org_gnu_glib_GObject_addEventHandler__Ljava_lang_String_2Ljava_lang_String_
 JNIEXPORT void JNICALL
 Java_org_gnu_glib_GObject_removeEventHandler(JNIEnv *env, jobject obj, jint sigid)
 {
-  g_signal_handler_disconnect(JGTKO(obj), sigid);
+  g_signal_handler_disconnect(getPointerFromHandle(env, obj), sigid);
 }
 
 
@@ -704,10 +696,11 @@ Java_org_gnu_glib_GObject_removeEventHandler(JNIEnv *env, jobject obj, jint sigi
  * Signature: (ILjava/lang/String;)Ljava/lang/Object;
  */
 JNIEXPORT jobject JNICALL Java_org_gnu_glib_GObject_getData
-  (JNIEnv *env, jobject obj, jint handle, jstring key)
+  (JNIEnv *env, jobject obj, jobject handle, jstring key)
 {
 	gchar *k = (gchar*)(*env)->GetStringUTFChars(env, key, NULL);
-	JGRef *ref = (JGRef*) g_object_get_data((GObject*)handle, k);
+        GObject *handle_g = (GObject *)getPointerFromHandle(env, handle);
+	JGRef *ref = (JGRef*) g_object_get_data(handle_g, k);
 	(*env)->ReleaseStringUTFChars(env, key, k);
 	if (ref == NULL){
 		return NULL;
@@ -730,13 +723,14 @@ jg_gobject_destroy(gpointer data)
  * Signature: (ILjava/lang/String;Ljava/lang/Object;)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_glib_GObject_setData
-  (JNIEnv *env, jobject obj, jint handle, jstring key, jobject data)
+  (JNIEnv *env, jobject obj, jobject handle, jstring key, jobject data)
 {
+        GObject *handle_g = (GObject *)getPointerFromHandle(env, handle);
 	gchar *k = (gchar*)(*env)->GetStringUTFChars(env, key, NULL);
 	JGRef *ref = g_new( JGRef, 1 );
 	ref->env = env;
 	ref->object = (* env)->NewGlobalRef(env, data);
-	g_object_set_data_full((GObject*)handle, 
+	g_object_set_data_full(handle_g,
 				k, 
 				ref,
 				jg_gobject_destroy
@@ -773,6 +767,16 @@ void logFunc(const gchar* logDomain, GLogLevelFlags logLevel, const gchar* messa
 			G_LOG_FLAG_FATAL | G_LOG_FLAG_RECURSION, logFunc, (gpointer)env);
 }
 
+/*
+ * Class:     org_gnu_glib_GObject
+ * Method:    getNullHandle
+ * Signature: ()Lorg/gnu/glib/Handle;
+ */
+JNIEXPORT jobject JNICALL Java_org_gnu_glib_GObject_getNullHandle
+(JNIEnv *env, jclass cls)
+{
+    return getHandleFromPointer(env, NULL);
+}
 
 #ifdef __cplusplus
 }
